﻿using System;
using System.Diagnostics;
using System.Globalization;
using System.IO;
using System.Linq;

namespace Sarnased
{
    class Program
    {
        // abistav struktuur Segment hoiab lõigu pikkust ja nurka järgmise lõiguga
        class Segment
        {
            private const double Epsilon = 0.000001;
            private readonly double _l;
            public double A;

            public Segment(double l, double x2, double y2, double x1, double y1)
            {
                _l = l; // pikkus

                double a1 = 180 * Math.Atan2(x1, y1) / Math.PI; // käesoleva lõigu tõus
                double a2 = 180 * Math.Atan2(x2, y2) / Math.PI; // järgmise lõigu tõus
                A = a2 - a1; // lõikude vaheline nurk on tõusude vahe

                // normaliseerime nurga, nii et see oleks alati -180 ja 180 vahel
                if (A > 180) A -= 360;
                if (A < -180) A += 360;
            }

            // kaks Segmenti loetakse võrdseks, kui nende pikkused ja nurgad on piisava täpsusega võrdsed
            public bool Equals(Segment s2)
            {
                return Math.Abs(_l - s2._l) < Epsilon && Math.Abs(A - s2.A) < Epsilon;
            }

            // debugimise abi
            public override string ToString()
            {
                return string.Format("{0} {1}", _l, A);
            }
        }

        static void Main(string[] args)
        {
            if (args.Length > 0 && args[0] == "all")
            {
                for (int i = 41; i <= 41; i++)
                {
                    string input = String.Format("input{0}.txt", i);
                    if (File.Exists(input))
                    {
                        Solve(input, input.Replace("in", "out"));
                    }
                }
            }
            else
            {
                if (File.Exists("nurkpsis.txt"))
                {
                    Solve("nurkpsis.txt", "nurkpval.txt");
                }
                else if(File.Exists("nurkgsis.txt"))
                {
                    Solve("nurkgsis.txt", "nurkgval.txt");
                }
                else
                {
                    Solve("nurkesis.txt", "nurkeval.txt");
                }
            }
        }

        private static void Solve(string input, string output)
        {
            // Stopwatch w = new Stopwatch();

            // w.Start();
            string[] lines = File.ReadAllLines(input);
            bool isPohi = lines.Length == 2;

            // Sama lahendus erinevate ryhmade jaoks
            var n = isPohi ? 3 : int.Parse(lines[0]);
            // Console.Write(w.Elapsed + " ");
            
            int[] p1 = lines[isPohi ? 0 : 1].Split().Select(int.Parse).ToArray();
            int[] p2 = lines[isPohi ? 1 : 2].Split().Select(int.Parse).ToArray();
            // Console.Write(w.Elapsed + " ");

            double[] x1 = new double[n];
            double[] x2 = new double[n];

            double[] y1 = new double[n];
            double[] y2 = new double[n];

            double[] l1 = new double[n];
            double[] l2 = new double[n];

            // leiame punktide vahelised vektorid:
            for (int i = 0; i < n; i++)
            {
                // x-koordinaat
                x1[i] = p1[(2 * i + 2) % (2 * n)] - p1[2 * i];
                y1[i] = p1[(2 * i + 3) % (2 * n)] - p1[2 * i + 1];

                // y-koordinaat
                x2[i] = p2[(2 * i + 2) % (2 * n)] - p2[2 * i];
                y2[i] = p2[(2 * i + 3) % (2 * n)] - p2[2 * i + 1];

                // lõigu pikkus
                l1[i] = Math.Sqrt(x1[i] * x1[i] + y1[i] * y1[i]);
                l2[i] = Math.Sqrt(x2[i] * x2[i] + y2[i] * y2[i]);
            }

            double perim1 = l1.Sum();
            double perim2 = l2.Sum();

            // sarnasustegur on ümbermõõtude suhe
            double ratio = perim1 / perim2;

            // mõlemale hulknurgale vastavad segmentide jadad
            Segment[] s1 = new Segment[n];
            Segment[] s2 = new Segment[n];
            for (int i = 0; i < n; i++)
            {
                s1[i] = new Segment(l1[i], x1[(i + 1) % n], y1[(i + 1) % n], x1[i], y1[i]);

                // teise hulknurga korrutame kohe sarnasusteguriga läbi
                s2[i] = new Segment(l2[i] * ratio, x2[(i + 1) % n], y2[(i + 1) % n], x2[i], y2[i]);
            }

            int res = -1;

            // Proovime, kas segmendijadad on võimalik omavahel vastavusse viia
            // neli varianti: 
            // - kujundid on kas omavahel peegeldatud või ei (siis on nurgad vastasmärgiga)
            // - punktid on kas samas järjekorras või vastupidises järjekorras
            for (int i = 0; i < 2; i++)
            {
                for (int j = 0; j < 2; j++)
                {
                    res = KmpMatch(s1, s2);
                    if (res > -1) break;
                    for (int k = 0; k < n; k++)
                    {
                        s2[k].A = -s2[k].A;  // muudame nurkade märgid
                    }
                }
                if (res > -1)
                {
                    if (i == 1) res = n + 1 - res;
                    break;
                }
                Array.Reverse(s2);
            }

            if (res == -1)
            {
                File.WriteAllText(output, "-1");
            }
            else
            {
                if(isPohi)
                    File.WriteAllText(output, ratio.ToString(CultureInfo.InvariantCulture));
                else
                    File.WriteAllLines(output, new[] { ratio.ToString(CultureInfo.InvariantCulture), res.ToString() });
            }

            // Console.WriteLine(w.Elapsed);
        }

        // Kasutame Knuth-Morris-Pratti algoritmi. 
        // vt põhjalikku selgitust https://en.wikipedia.org/wiki/Knuth-Morris-Pratt_algorithm
        // Kui võtta teine hulkurk kahekordselt, peab esimene esinema selle sees alamjadana
        private static int KmpMatch(Segment[] pat, Segment[] str)
        {
            int m = pat.Length;
            int n = str.Length;
            int i = 0;
            int j = 0;
            int[] lps = new int[m];

            ComputeLpsArray(pat, m, lps);  // leiame iga märgi jaoks, kui palju me peame sealt backtrackima

            while (i < 2 * n)  // loeme teist hulkurka kahekordselt
            {
                if (pat[j].Equals(str[i % n]))
                {
                    j++;
                    i++;
                }

                if (j == m)
                {
                    return i - j + 1;
                }
                else if (i < 2 * n && !pat[j].Equals(str[i % n]))
                {
                    if (j != 0)
                        j = lps[j - 1];
                    else
                        i++;
                }
            }

            return -1;
        }

        private static void ComputeLpsArray(Segment[] pat, int m, int[] lps)
        {
            int len = 0;
            int i = 1;

            lps[0] = 0;

            while (i < m)
            {
                if (pat[i].Equals(pat[len]))
                {
                    len++;
                    lps[i] = len;
                    i++;
                }
                else
                {
                    if (len != 0)
                    {
                        len = lps[len - 1];
                    }
                    else
                    {
                        lps[i] = 0;
                        i++;
                    }
                }
            }
        }
    }
}
